@@ -8,6 +8,7 @@ import os
 import numpy as np
 
 import resqpy.crs as rqc
+import resqpy.derived_model
 import resqpy.grid as grr
 import resqpy.model as rq
 import resqpy.olio.fine_coarse as fc
@@ -16,7 +17,7 @@ import resqpy.olio.xml_et as rqet
 import resqpy.property as rqp
 import resqpy.rq_import as rqi
 
-from resqpy.derived_model._common import _write_grid
+import resqpy.derived_model._common as rqdm_c
 
 
 def refined_grid(epc_file,
@@ -127,16 +128,20 @@ def refined_grid(epc_file,
         model_in.h5_release()
 
     if new_epc_file:
-        _write_grid(new_epc_file, grid, property_collection = collection, grid_title = new_grid_title, mode = 'w')
+        rqdm_c._write_grid(new_epc_file,
+                           grid,
+                           property_collection = collection,
+                           grid_title = new_grid_title,
+                           mode = 'w')
     else:
         ext_uuid, _ = model.h5_uuid_and_path_for_node(rqet.find_nested_tags(source_grid.root, ['Geometry', 'Points']),
                                                       'Coordinates')
-        _write_grid(epc_file,
-                    grid,
-                    ext_uuid = ext_uuid,
-                    property_collection = collection,
-                    grid_title = new_grid_title,
-                    mode = 'a')
+        rqdm_c._write_grid(epc_file,
+                           grid,
+                           ext_uuid = ext_uuid,
+                           property_collection = collection,
+                           grid_title = new_grid_title,
+                           mode = 'a')
 
     return grid
 
@@ -213,7 +218,7 @@ def _refined_unfaulted_grid(model, source_grid, fine_coarse):
     # inherit the coordinate reference system used by the grid geometry
     grid.crs_uuid = source_grid.crs_uuid
     if source_grid.model is not model:
-        model.duplicate_node(source_grid.model.root_for_uuid(source_grid, grid.crs_uuid), add_as_part = True)
+        model.duplicate_node(source_grid.model.root_for_uuid(grid.crs_uuid), add_as_part = True)
     grid.crs = rqc.Crs(model, uuid = grid.crs_uuid)
 
     refined_points = np.empty((grid.nk_plus_k_gaps + 1, grid.nj + 1, grid.ni + 1, 3))
@@ -316,6 +321,11 @@ def _refined_unfaulted_grid(model, source_grid, fine_coarse):
 
 def _inherit_properties(source_grid, grid, fine_coarse, inherit_realization, inherit_all_realizations):
     source_collection = source_grid.extract_property_collection()
+    source_collection = rqp.selective_version_of_collection(source_collection,
+                                                            indexable = 'cells',
+                                                            count = 1,
+                                                            points = False)
+    # todo: support other indexable elements, especially columns
     collection = None
     if source_collection is not None:
         #  do not inherit the inactive property array by this mechanism
