@@ -2,7 +2,8 @@
 
 import warnings
 
-import resqpy
+import resqpy.grid as grr
+import resqpy.unstructured as rug
 import resqpy.olio.xml_et as rqet
 
 
@@ -50,13 +51,12 @@ def is_regular_grid(grid_root):
     return grid_flavour(grid_root) == 'IjkBlockGrid'
 
 
-def any_grid(parent_model, uuid = None, grid_root = None, find_properties = True):
+def any_grid(parent_model, uuid = None, find_properties = True):
     """Returns a Grid or RegularGrid or UnstructuredGrid object depending on the extra metadata in the xml.
 
     arguments:
         parent_model (Model): the model within which the grid exists
         uuid (UUID): the uuid of the grid object to be instantiated
-        grid_root (lxml.Element, DEPRECATED): an alternative to passing the uuid
         find_properties (bool, default True): passed onward to the instantiation method
 
     note:
@@ -64,22 +64,15 @@ def any_grid(parent_model, uuid = None, grid_root = None, find_properties = True
         Grid, RegularGrid, UnstructuredGrid, TetraGrid, HexaGrid, PyramidGrid, PrismGrid
     """
 
-    import resqpy.unstructured as rug
-
-    if grid_root is not None:
-        warnings.warn('Deprecated: use of grid_root arg to any_grid(); use uuid instead', DeprecationWarning)
-        if uuid is None:
-            uuid = rqet.uuid_for_part_root(grid_root)
-
     assert uuid is not None
 
     flavour = grid_flavour(parent_model.root_for_uuid(uuid))
     if flavour is None:
         return None
     if flavour == 'IjkGrid':
-        return resqpy.grid.Grid(parent_model, uuid = uuid, find_properties = find_properties)
+        return grr.Grid(parent_model, uuid = uuid, find_properties = find_properties)
     if flavour == 'IjkBlockGrid':
-        return resqpy.grid.RegularGrid(parent_model, extent_kji = None, uuid = uuid, find_properties = find_properties)
+        return grr.RegularGrid(parent_model, extent_kji = None, uuid = uuid, find_properties = find_properties)
     if flavour == 'UnstructuredGrid':
         return rug.UnstructuredGrid(parent_model, uuid = uuid, find_properties = find_properties)
     if flavour == 'TetraGrid':
