@@ -8,23 +8,24 @@ import math as maths
 import numpy as np
 
 import resqpy.crs as rqc
+import resqpy.grid
 import resqpy.olio.transmission as rqtr
 import resqpy.olio.uuid as bu
 import resqpy.olio.vector_utilities as vec
 import resqpy.olio.xml_et as rqet
-from resqpy.olio.xml_namespaces import curly_namespace as ns
 import resqpy.property as rprop
+from resqpy.olio.xml_namespaces import curly_namespace as ns
 
-from ._grid import Grid
-from ._grid_types import is_regular_grid
-from ._create_grid_xml import _add_constant_pillar_geometry_is_defined, _add_constant_cell_geometry_is_defined
+import resqpy.grid._grid as grr_g
+import resqpy.grid._grid_types as grr_gt
+import resqpy.grid._create_grid_xml as grr_xml
 
 # for a regular grid, the ...is_defined xml is created as a constant bool array, if the following set True
 always_write_pillar_geometry_is_defined = True  # required True for Fesapi interoperability (xsd compliance)
 always_write_cell_geometry_is_defined = False
 
 
-class RegularGrid(Grid):
+class RegularGrid(grr_g.Grid):
     """Class for completely regular block grids, usually aligned with xyz axes."""
 
     # WIP: use RESQML lattice like geometry specification
@@ -176,7 +177,7 @@ class RegularGrid(Grid):
         else:
 
             assert bu.is_uuid(uuid)
-            assert is_regular_grid(parent_model.root_for_uuid(uuid))
+            assert grr_gt.is_regular_grid(parent_model.root_for_uuid(uuid))
             super().__init__(parent_model,
                              uuid = uuid,
                              find_properties = find_properties,
@@ -466,12 +467,15 @@ class RegularGrid(Grid):
         centres += self.block_origin[:2] + 0.5 * np.sum(self.block_dxyz_dkji[1:, :2], axis = 0)
         return centres
 
-    def volume(self, cell_kji0 = None):
+    def volume(self, cell_kji0 = None, required_uom = None):
         """Returns bulk rock volume of cell or numpy array of bulk rock volumes for all cells.
 
         arguments:
            cell_kji0 (optional): if present, the (k, j, i) indices of the individual cell for which the
                                  volume is required; zero based indexing
+           required_uom (str, optional): if present, the RESQML unit of measure (for quantity volume) that
+                                 the volumes will be returned in; if None, the grid's CRS z units cubed
+                                 will be used
 
         returns:
            float, being the volume of cell identified by cell_kji0;
@@ -479,12 +483,14 @@ class RegularGrid(Grid):
 
         notes:
            the function can be used to find the volume of a single cell, or all cells;
-           grid's coordinate reference system must use same units in z as xy (projected);
-           units of result are implicitly determined by coordinates in grid's coordinate reference system;
            the method currently assumes that the primary i, j, k axes are mutually orthogonal
         """
 
+        required_uom = self.get_volume_uom(required_uom)
+        conversion_factor = self.get_volume_conversion_factor(required_uom)
         vol = np.product(vec.naive_lengths(self.block_dxyz_dkji))
+        if conversion_factor is not None:
+            vol *= conversion_factor
         if cell_kji0 is not None:
             return vol
         return np.full((self.nk, self.nj, self.ni), vol)
@@ -680,9 +686,9 @@ class RegularGrid(Grid):
             geom = rqet.find_tag(node, 'Geometry')
             assert geom is not None
             if always_write_pillar_geometry_is_defined and rqet.find_tag(geom, 'PillarGeometryIsDefined') is None:
-                _add_constant_pillar_geometry_is_defined(geom, self.extent_kji)
+                grr_xml._add_constant_pillar_geometry_is_defined(geom, self.extent_kji)
             if always_write_cell_geometry_is_defined and rqet.find_tag(geom, 'CellGeometryIsDefined') is None:
-                _add_constant_cell_geometry_is_defined(geom, self.extent_kji)
+                grr_xml._add_constant_cell_geometry_is_defined(geom, self.extent_kji)
 
         if add_cell_length_properties:
             axes_lengths_kji = self.axial_lengths_kji()
