@@ -8,17 +8,15 @@ able to do much with data stored in this way.
 # Nexus is a registered trademark of Halliburton
 
 import logging
-import os
 
+log = logging.getLogger(__name__)
+
+import os
 import numpy as np
 import pandas as pd
 
-import resqpy.olio.xml_et as rqet
 from resqpy.olio.dataframe import DataFrame
-
-version = '27th July 2021'
-
-log = logging.getLogger(__name__)
+import resqpy.olio.xml_et as rqet
 
 
 class RelPerm(DataFrame):
@@ -121,7 +119,6 @@ class RelPerm(DataFrame):
 
         super().__init__(model,
                          uuid = uuid,
-                         support_root = None,
                          df = df,
                          uom_list = uom_list,
                          realization = realization,
