@@ -1,17 +1,15 @@
 """RESQML Feature and Interpretation classes."""
 
-version = '9th November 2021'
-
 # most feature and interpretation classes catered for here
 # stratigraphic classes in strata.py
 
 import logging
 
 log = logging.getLogger(__name__)
-log.debug('organize_old.py version ' + version)
 
-from ._utils import alias_for_attribute, equivalent_extra_metadata
 import resqpy.olio.uuid as bu
+import resqpy.organize
+import resqpy.organize._utils as ou
 from resqpy.olio.base import BaseResqpy
 
 
@@ -19,12 +17,16 @@ class GeobodyFeature(BaseResqpy):
     """Class for RESQML Geobody Feature objects (note: definition may be incomplete in RESQML 2.0.1)."""
 
     resqml_type = "GeobodyFeature"
-    feature_name = alias_for_attribute("title")
+    feature_name = ou.alias_for_attribute("title")
 
-    def __init__(self, parent_model, uuid = None, feature_name = None, extra_metadata = None):
+    def __init__(self, parent_model, uuid = None, feature_name = None, originator = None, extra_metadata = None):
         """Initialises a geobody feature object."""
 
-        super().__init__(model = parent_model, uuid = uuid, title = feature_name, extra_metadata = extra_metadata)
+        super().__init__(model = parent_model,
+                         uuid = uuid,
+                         title = feature_name,
+                         originator = originator,
+                         extra_metadata = extra_metadata)
 
     def is_equivalent(self, other, check_extra_metadata = True):
         """Returns True if this feature is essentially the same as the other; otherwise False."""
@@ -33,7 +35,7 @@ class GeobodyFeature(BaseResqpy):
             return False
         if self is other or bu.matching_uuids(self.uuid, other.uuid):
             return True
-        if check_extra_metadata and not equivalent_extra_metadata(self, other):
+        if check_extra_metadata and not ou.equivalent_extra_metadata(self, other):
             return False
         return self.feature_name == other.feature_name
 
