@@ -2,23 +2,18 @@
 
 # Nexus is a trademark of Halliburton
 
-import warnings
-import resqpy.property
-
 import logging
 
 log = logging.getLogger(__name__)
 
+import warnings
 import numpy as np
 
+import resqpy.property as rqp
 import resqpy.olio.uuid as bu
 import resqpy.olio.xml_et as rqet
 import resqpy.weights_and_measures as bwam
 
-#from .propertykind import PropertyKind
-#from .propertycollection import PropertyCollection
-#from .property import Property
-
 # the following resqml property kinds and facet types are 'known about' by this module in relation to nexus
 # other property kinds should be handled okay but without any special treatment
 # see property_kind_and_facet_from_keyword() for simulator keyword to property kind and facet mapping
@@ -167,14 +162,16 @@ def property_kind_and_facet_from_keyword(keyword):
         property_kind = 'permeability rock'
         (facet_type, facet) = _facet_info_for_dir_ch(lk[-1])
     elif lk[:5] == 'trans' or (len(lk) == 2 and lk[0] == 't'):  # transmissibility (for unit viscosity)
-        property_kind = 'transmissibility'
-        (facet_type, facet) = _facet_info_for_dir_ch(lk[-1])
-
-
-#   elif lk == 'sal':    # todo: salinity; local property kind needed; various units possible in Nexus
+        if 'mult' in lk:
+            property_kind = 'transmissibility multiplier'
+        else:
+            property_kind = 'transmissibility'
+        if lk != 'transmissibility':
+            (facet_type, facet) = _facet_info_for_dir_ch(lk[-1])
+    # elif lk == 'sal':    # todo: salinity; local property kind needed; various units possible in Nexus
     elif lk == 'livecell' or lk.startswith('act'):
         property_kind = 'active'  # local property kind, see RESQML (2.0.1) usage guide, section 11.17
-    elif lk[0] == 'i' or lk.startswith('reg') or lk.startswith('creg'):
+    elif len(lk) <= 8 and (lk[0] == 'i' or lk.startswith('reg') or lk.startswith('creg')):
         property_kind = 'region initialization'  # local property kind, see RESQML (2.0.1) usage guide, section 11.18
         if lk[0] == 'i':
             facet_type = 'what'
@@ -500,63 +497,73 @@ def _guess_uom_gor_ogr(property_kind, from_crs):
     return None
 
 
-def selective_version_of_collection(
-        collection,
-        realization = None,
-        support_uuid = None,
-        grid = None,  # for backward compatibility
-        uuid = None,
-        continuous = None,
-        points = None,
-        count = None,
-        indexable = None,
-        property_kind = None,
-        facet_type = None,
-        facet = None,
-        citation_title = None,
-        time_series_uuid = None,
-        time_index = None,
-        uom = None,
-        string_lookup_uuid = None,
-        categorical = None,
-        title = None,
-        title_mode = None,
-        related_uuid = None,
-        const_value = None):
+def selective_version_of_collection(collection,
+                                    realization = None,
+                                    support_uuid = None,
+                                    uuid = None,
+                                    continuous = None,
+                                    points = None,
+                                    count = None,
+                                    indexable = None,
+                                    property_kind = None,
+                                    facet_type = None,
+                                    facet = None,
+                                    citation_title = None,
+                                    time_series_uuid = None,
+                                    time_index = None,
+                                    uom = None,
+                                    string_lookup_uuid = None,
+                                    categorical = None,
+                                    title = None,
+                                    title_mode = None,
+                                    related_uuid = None,
+                                    const_value = None):
     """Returns a new PropertyCollection with those parts which match all arguments that are not None.
 
     arguments:
-       collection: an existing PropertyCollection from which a subset will be returned as a new object;
-                   the existing collection might often be the 'main' collection holding all the properties
-                   for a supporting representation (grid or wellbore frame)
-
-    Other optional arguments:
-    realization, support_uuid, grid, uuid, continuous, points, count, indexable, property_kind, facet_type, facet,
-    citation_title, time_series_uuid, time_index, uom, string_lookup_uuid, categorical, title, related_uuid:
-    title_mode (str, optional): if present, one of 'is', 'starts', 'ends', 'contains', 'is not',
-        'does not start', 'does not end', 'does not contain'; None is the same as 'is'
-
-    for each of these arguments: if None, then all members of collection pass this filter;
-    if not None then only those members with the given value pass this filter;
-    special values: '*' any non-None value passes; 'none' only None passes
-    finally, the filters for all the attributes must be passed for a given member
-    to be included in the returned collection; title is a synonym for the citation_title argument;
-    related_uuid will pass if a soft relationship exists
+       collection (PropertyCollection): an existing collection from which a subset will be returned as a new object
+       realization (int, optional): realization number to filter on
+       support_uuid (UUID or str, optional): UUID of supporting representation, to filter on
+       uuid (UUID or str, optional): a property uuid to select a singleton property from the collection
+       continuous (bool, optional): if True, continuous properties are selected; if False, discrete and categorical
+       points (bool, optional): if True, points properties are selected; if False, they are excluded
+       count (int, optional): a count value to filter on
+       indexable (str, optional): indexable elements flavour to filter on
+       property_kind (str, optional): property kind to filter on (commonly used)
+       facet_type (str, optional): a facet_type to filter on (must be present for property to be selected)
+       facet (str, optional): a facet value to filter on (if used, facet_type should be specified)
+       citation_title (str, optional): citation to title to filter on; see also title_mode argument
+       time_series_uuid (UUID or str, optional): UUID of a TimeSeries to filter on
+       time_index (int, optional): a time series time index to filter on
+       uom (str, optional): unit of measure to filter on
+       string_lookup_uuid (UUID or str, optional): UUID of a string lookup table to filter on
+       categorical (bool, optional): if True, only categorical properties are selected; if False they are excluded
+       title (str, optional): synonymous with citation_title argument
+       title_mode (str, optional): if present, one of 'is', 'starts', 'ends', 'contains', 'is not',
+           'does not start', 'does not end', 'does not contain'; None is the same as 'is'; will default to 'is'
+           if not specified and title or citation_title argument is present
+       related_uuid (UUID or str, optional): only properties with direct relationship to this uuid are selected
+       const_value (float or int, optional): only properties flagged as constant, with given value, are selected
 
     returns:
        a new PropertyCollection containing those properties which match the filter parameters that are not None
 
-    note:
-       the grid keyword argument is maintained for backward compatibility: support_uuid argument takes precedence;
-       the categorical boolean argument can be used to select only
-       categorical (or non-categorical) properties, even though this is not explicitly held as a field in the
-       internal dictionary
+    notes:
+       the existing collection might often be the 'main' collection holding all the properties
+       for a supporting representation (eg. grid, blocked well or wellbore frame);
+       for each of the filtering arguments: if None, then all members of collection pass this filter;
+       if not None then only those members with the given value pass this filter;
+       special values: '*' any non-None value passes; 'none' only None passes;
+       citation_title (or its synonym title) uses string filtering in association with title_mode argument;
+       finally, the filters for all the attributes must be passed for a given member
+       to be included in the returned collection; title is a synonym for the citation_title argument;
+       related_uuid will pass if any relationship exists ('hard' or 'soft');
+       the categorical boolean argument can be used to select only categorical (or non-categorical) properties,
+       even though this is not explicitly held as a field in the internal dictionary
     """
 
     assert collection is not None
-    view = resqpy.property.PropertyCollection()
-    if support_uuid is None and grid is not None:
-        support_uuid = grid.uuid
+    view = rqp.PropertyCollection()
     if support_uuid is not None:
         view.set_support(support_uuid = support_uuid, model = collection.model)
     if realization is not None:
@@ -602,7 +609,7 @@ def property_over_time_series_from_collection(collection, example_part):
 
     assert collection is not None and example_part is not None
     assert collection.part_in_collection(example_part)
-    view = resqpy.property.PropertyCollection()
+    view = rqp.PropertyCollection()
     if collection.support_uuid is not None:
         view.set_support(support_uuid = collection.support_uuid, model = collection.model)
     if collection.realization is not None:
@@ -727,19 +734,19 @@ def write_hdf5_and_create_xml_for_active_property(model,
                                                   time_index = None):
     """Writes hdf5 data and creates xml for an active cell property; returns uuid."""
 
-    active = resqpy.property.Property.from_array(parent_model = model,
-                                                 cached_array = active_property_array,
-                                                 source_info = None,
-                                                 keyword = title,
-                                                 support_uuid = support_uuid,
-                                                 property_kind = 'active',
-                                                 local_property_kind_uuid = None,
-                                                 indexable_element = 'cells',
-                                                 discrete = True,
-                                                 time_series_uuid = time_series_uuid,
-                                                 time_index = time_index,
-                                                 realization = realization,
-                                                 find_local_property_kind = True)
+    active = rqp.Property.from_array(parent_model = model,
+                                     cached_array = active_property_array,
+                                     source_info = None,
+                                     keyword = title,
+                                     support_uuid = support_uuid,
+                                     property_kind = 'active',
+                                     local_property_kind_uuid = None,
+                                     indexable_element = 'cells',
+                                     discrete = True,
+                                     time_series_uuid = time_series_uuid,
+                                     time_index = time_index,
+                                     realization = realization,
+                                     find_local_property_kind = True)
     return active.uuid
 
 
@@ -749,3 +756,79 @@ def check_and_warn_property_kind(pk, activity):
         warnings.warn(
             f"abstract property kind '{pk}', whilst {activity}, will be or have been replaced by local property kind")
         # raise ValueError
+
+
+def property_parts(model,
+                   obj_type,
+                   parts_list = None,
+                   property_kind = None,
+                   facet_type = None,
+                   facet = None,
+                   related_uuid = None):
+    """Returns list of property parts from model matching filters."""
+
+    def facet_match(root, facet_type, facet):
+        if not facet_type and not facet:
+            return True
+        assert facet_type and facet is not None
+        facets = rqet.list_of_tag(root, 'Facet')
+        if facet_type == 'none' and facets:
+            return False
+        for f_node in facets:
+            if rqet.find_tag_text(f_node, 'Facet') == facet_type:
+                if facet == 'none':
+                    return False
+                if facet == '*':
+                    return True
+                return rqet.find_tag_text(f_node, 'Value') == str(facet)
+        if facet == 'none':
+            return True
+        return False
+
+    if not obj_type.endswith('Property'):
+        obj_type += 'Property'
+    assert obj_type in ['ContinuousProperty', 'DiscreteProperty', 'CategoricalProperty', 'PointsProperty']
+    parts = model.parts(parts_list = parts_list, obj_type = obj_type, related_uuid = related_uuid)
+    if property_kind:
+        pk_parts = []
+        for part in parts:
+            root = model.root_for_part(part)
+            node = rqet.find_nested_tags(root, ['PropertyKind', 'Kind'])
+            if node is None:
+                # following relies on title in reference xml matching that of the local proparty kind
+                node = rqet.find_nested_tags(root, ['PropertyKind', 'LocalPropertyKind', 'Title'])
+                assert node is not None
+            if node.text != property_kind and (property_kind not in ['rock permeability', 'permeability rock'] or
+                                               node.text not in ['rock permeability', 'permeability rock']):
+                continue
+            if facet_match(root, facet_type, facet):
+                pk_parts.append(part)
+        parts = pk_parts
+    elif facet_type and facet is not None:
+        f_parts = []
+        for part in parts:
+            root = model.root_for_part(part)
+            if facet_match(root, facet_type, facet):
+                pk_parts.append(part)
+    return parts
+
+
+def property_part(model,
+                  obj_type,
+                  parts_list = None,
+                  property_kind = None,
+                  facet_type = None,
+                  facet = None,
+                  related_uuid = None):
+    """Returns individual property part from model matching filters."""
+    parts = property_parts(model,
+                           obj_type,
+                           parts_list = parts_list,
+                           property_kind = property_kind,
+                           facet_type = facet_type,
+                           facet = facet,
+                           related_uuid = related_uuid)
+    if parts is None or len(parts) == 0:
+        return None
+    assert len(parts) == 1, 'more than one property part matches criteria'
+    return parts[0]
