@@ -1,6 +1,4 @@
-"""_pointset.py: pointset class based on resqml standard."""
-
-version = '18th February 2022'
+"""PointSet class based on RESQML standard."""
 
 # RMS and ROXAR are registered trademarks of Roxar Software Solutions AS, an Emerson company
 # GOCAD is also a trademark of Emerson
@@ -16,11 +14,12 @@ import resqpy.olio.uuid as bu
 import resqpy.olio.vector_utilities as vec
 import resqpy.olio.write_hdf5 as rwh5
 import resqpy.olio.xml_et as rqet
+import resqpy.surface
+import resqpy.surface._base_surface as rqsb
 from resqpy.olio.xml_namespaces import curly_namespace as ns
-from ._base_surface import BaseSurface
 
 
-class PointSet(BaseSurface):
+class PointSet(rqsb.BaseSurface):
     """Class for RESQML Point Set Representation within resqpy model object."""  # TODO: Work in Progress
 
     resqml_type = 'PointSetRepresentation'
@@ -141,12 +140,7 @@ class PointSet(BaseSurface):
             charisma_file: a charisma 3d interpretation file
         """
         with open(charisma_file, 'r') as surf:
-            for i, line in enumerate(surf.readlines()):
-                if i == 0:
-                    cpoints = np.array([[float(x) for x in line.split()[6:]]])
-                else:
-                    curr = np.array([[float(x) for x in line.split()[6:]]])
-                    cpoints = np.concatenate((cpoints, curr))
+            cpoints = np.loadtxt(surf, usecols = (6, 7, 8), encoding = 'uft-8')
         self.add_patch(cpoints)
         assert self.crs_uuid is not None, 'crs uuid missing when establishing point set from charisma file'
         if not self.title:
@@ -159,12 +153,13 @@ class PointSet(BaseSurface):
             irap_file: a IRAP classic points format file
         """
         with open(irap_file, 'r') as points:
-            for i, line in enumerate(points.readlines()):
-                if i == 0:
-                    cpoints = np.array([[float(x) for x in line.split(" ")]])
-                else:
-                    curr = np.array([[float(x) for x in line.split(" ")]])
-                    cpoints = np.concatenate((cpoints, curr))
+            cpoints = np.loadtxt(points, encoding = 'uft-8')
+            # for i, line in enumerate(points.readlines()):
+            #     if i == 0:
+            #         cpoints = np.array([[float(x) for x in line.split(" ")]])
+            #     else:
+            #         curr = np.array([[float(x) for x in line.split(" ")]])
+            #         cpoints = np.concatenate((cpoints, curr))
         self.add_patch(cpoints)
         assert self.crs_uuid is not None, 'crs uuid missing when establishing point set from irap file'
         if not self.title:
@@ -338,8 +333,8 @@ class PointSet(BaseSurface):
         """
 
         def try_angle(pset, theta):
-            p = pset.full_array_ref().copy()
-            m = vec.rotation_matrix_3d_axial(0, theta)
+            p = pset.full_array_ref()
+            m = vec.rotation_matrix_3d_axial(2, theta)
             p = vec.rotate_array(m, p)[:, :2]
             dxy = np.nanmax(p, axis = 0) - np.nanmin(p, axis = 0)
             return dxy
@@ -347,16 +342,19 @@ class PointSet(BaseSurface):
         assert self.patch_count > 0
         theta = 0.0
         min_dxy = try_angle(self, theta)
-        min_area = np.sum(min_dxy * min_dxy)
+        min_area = min_dxy[0] * min_dxy[1]
+        min_theta = theta
         while theta < 180.0 - delta_theta:
             theta += delta_theta
             dxy = try_angle(self, theta)
-            area = np.sum(dxy * dxy)
+            area = dxy[0] * dxy[1]
             if area < min_area:
-                min_dxy = dxy
-        if dxy[0] <= dxy[1]:
-            return dxy[0], dxy[1], theta
-        return dxy[1], dxy[0], theta + 90.0 if theta < 90.0 else theta - 90.0
+                min_dxy = dxy.copy()
+                min_area = area
+                min_theta = theta
+        if min_dxy[0] <= min_dxy[1]:
+            return min_dxy[0], min_dxy[1], min_theta
+        return min_dxy[1], min_dxy[0], min_theta + 90.0 if min_theta < 90.0 else min_theta - 90.0
 
     def full_array_ref(self):
         """Return a single numpy float array of shape (N, 3) containing all points from all patches.
